@@ -7,12 +7,18 @@ import warnings
 import weakref
 from collections.abc import Callable
 from ssl import SSLError
+from typing import Any
 
 from tornado import web
 from tornado.httpclient import HTTPClientError, HTTPRequest
 from tornado.httpserver import HTTPServer
 from tornado.iostream import StreamClosedError
-from tornado.websocket import WebSocketClosedError, WebSocketHandler, websocket_connect
+from tornado.websocket import (
+    WebSocketClientConnection,
+    WebSocketClosedError,
+    WebSocketHandler,
+    websocket_connect,
+)
 
 import dask
 
@@ -47,7 +53,7 @@ BIG_BYTES_SHARD_SIZE = dask.utils.parse_bytes(
 
 
 class WSHandler(WebSocketHandler):
-    def __init__(
+    def __init__(  # type: ignore[no-untyped-def]
         self,
         application,
         request,
@@ -99,7 +105,12 @@ class WSHandler(WebSocketHandler):
 
 
 class WSHandlerComm(Comm):
-    def __init__(self, handler, deserialize: bool = True, allow_offload: bool = True):
+    def __init__(
+        self,
+        handler: WSHandler,
+        deserialize: bool = True,
+        allow_offload: bool = True,
+    ):
         self.handler = handler
         self.allow_offload = allow_offload
         super().__init__(deserialize=deserialize)
@@ -158,7 +169,9 @@ class WSHandlerComm(Comm):
 
     @property
     def peer_address(self) -> str:
-        return self.handler.request.remote_ip + ":0"
+        ip = self.handler.request.remote_ip
+        assert isinstance(ip, str)
+        return ip + ":0"
 
     def closed(self):
         return (
@@ -175,7 +188,12 @@ class WSHandlerComm(Comm):
 class WS(Comm):
     prefix = "ws://"
 
-    def __init__(self, sock, deserialize: bool = True, allow_offload: bool = True):
+    def __init__(
+        self,
+        sock: WebSocketClientConnection,
+        deserialize: bool = True,
+        allow_offload: bool = True,
+    ):
         self._closed = False
         super().__init__(deserialize=deserialize)
         self.sock = sock
@@ -298,9 +316,9 @@ class WSListener(Listener):
         self,
         address: str,
         handler: Callable,
-        deserialize=True,
-        allow_offload=False,
-        **connection_args,
+        deserialize: bool = True,
+        allow_offload: bool = False,
+        **connection_args: Any,
     ):
         if not address.startswith(self.prefix):
             address = f"{self.prefix}{address}"
