@@ -1,9 +1,11 @@
-from distutils.version import LooseVersion
+from __future__ import annotations
+
 from numbers import Number
 
 import bokeh
 from bokeh.core.properties import without_property_validation
 from bokeh.io import curdoc
+from packaging.version import parse as parse_version
 from tlz.curried import first
 
 try:
@@ -11,9 +13,7 @@ try:
 except ImportError:
     np = None  # type: ignore
 
-
-BOKEH_VERSION = LooseVersion(bokeh.__version__)
-
+BOKEH_VERSION = parse_version(bokeh.__version__)
 
 PROFILING = False
 
